package fr.umlv.foogle;

import java.util.Collection;

/** Represents a context strategy i.e. how to obtain a context
 *  of the indexed words.
 *  
 * @author Remi Forax
 * 
 * @see FoogleFacade#getAllContextStrategies()
 * @see FoogleFacade#createIndex(ContextStrategy)
 */
public interface ContextStrategy {
  /** Retruns the name of the Strategy.
   * @return the name of the current strategy.
   */
  public String getName();
  
  /** Returns the context of a result,
   *  this result must be created by a query on an
   *  index that use the current strategy.
   * 
   * @param result of a qery on an index that
   *  used this strategy.
   * @return an unmodifiable list of words representing
   *  the context of the result.
   *  
   * @throws IllegalArgumentException if the result is not created
   *  with an index using this strategy.
   *  
   *@see Index#getContextStrategy()
   */
  public Collection<? extends CharSequence> getContext(Result result);
}
