package fr.umlv.foogle;

/** Represents a query to an index.
 *  The query is specific to an index.
 *  
 * @author Remi Forax
 * 
 * @see QueryFactory
 * @see FoogleFacade#createQueryFactory(Index)
 */
public interface Query {
  /** Query the index to find results corresponding to a
   *  specific query.
   * 
   * @return the result of the query.
   * 
   * @see Query#execute(int)
   */
  public Iterable<? extends Result> execute();
  
  /** Query the index to find results corresponding to a
   *  specific query.
   *  
   *  @param maxCount a positive integer 
   * 
   * @return the result of the query.
   * 
   * @see QueryFactory
   * @see FoogleFacade#createQueryBuilder(String)
   */
  public Iterable<? extends Result> execute(int maxCount);
}
