package fr.umlv.foogle;

import java.util.regex.Pattern;

/** Factory used to create index queries,
 *  The factory is specific to an index.
 *  
 *  All results returned by {@link Query#execute()}
 *  on these queries are garanteed to have distinct
 *  line numbers (see {@link Result#getLine()}).
 *
 * @author Remi Forax
 */
public interface QueryFactory {
  /** Creates a query for a simple word.
   * 
   * @param word the queried word.
   * @return a new query.
   */
  public Query query(CharSequence word);
  
  /** Creates a query for a regex.
   * 
   * @param pattern the queried regex.
   * @return a new query.
   */
  public Query query(Pattern pattern);
  
  /** Create a new query by oring query1 and query2.
   *  
   * @param query1 the first query.
   * @param query2 the second query.
   * @return the new query.
   */
  public Query or(Query query1,Query query2);
  
  /** Create a new query by anding query1 and query2.
   * @param query1 the first query.
   * @param query2 the second query.
   * @return the new query.
   */
  public Query and(Query query1,Query query2);
}
