package fr.umlv.foogle;

import java.util.Scanner;
import java.util.regex.Pattern;

/** This interface specifies
 *  how words are delimited in a text
 *  using a regex pattern
 *  {@link #getDelimiterRegex()}
 *  and which word are indexed
 *  {@link #isIndexable(CharSequence)}.
 * 
 * @author Rémi Forax
 */
public interface WordAccepter {
  /** Returns the regex pattern used to separate words.
   * @return a regex pattern.
   * 
   * @see Scanner#useDelimiter(Pattern)
   */
  public Pattern getDelimiterRegex();
  
  /** Indicates if a word should be indexed or not.
   * @param word the word
   * @return true if the word is indexable, false otherwise.
   */
  public boolean isIndexable(CharSequence word);
}
